@@ -15,6 +15,7 @@
 #include <time.h>
 #include <config.h>
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <gdk/gdkx.h>
 #include <applet-widget.h>
 
@@ -271,6 +272,7 @@ main(int argc, char **argv)
 {
         applet_widget_init("cpumemusage_applet", VERSION, argc, argv,
 			   NULL, 0, NULL);
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-cpu-mem.png");
 
 	applet = applet_widget_new("cpumemusage_applet");
 	if (!applet)
