@@ -25,6 +25,7 @@
 #include <sys/stat.h>
 #include <gnome.h>
 #include <applet-widget.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <signal.h>
 
 #include "gnotes_applet.h"
@@ -156,6 +157,8 @@ int main(int argc, char **argv)
     gnotes_init();
 
     applet_widget_init("gnotes_applet", VERSION, argc, argv, NULL, 0, NULL);
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gnotes.png");
+
 
     smClient = newGnomeClient();        /* initialize session management */
 
@@ -175,6 +178,15 @@ int main(int argc, char **argv)
     gtk_widget_show(gnotes_button);
     gtk_widget_show(gnotes.applet);
 
+
+    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "raise-notes",
+                                    _("Raise Notes"), gnotes_raise, 0);
+    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "lower-notes",
+                                    _("Lower Notes"), gnotes_lower, 0);
+    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "hide-notes",
+                                    _("Hide Notes"), gnotes_hide, 0);
+    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "show-notes",
+                                    _("Show Notes"), gnotes_show, 0);
     applet_widget_register_stock_callback(APPLET_WIDGET(gnotes.applet),
                                           "properties", GNOME_STOCK_MENU_PROP,
                                           _("Properties..."), properties_show,
@@ -186,15 +198,6 @@ int main(int argc, char **argv)
                                           "about", GNOME_STOCK_MENU_ABOUT,
                                           _("About..."), about, NULL);
 
-    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "raise-notes",
-                                    _("Raise Notes"), gnotes_raise, 0);
-    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "lower-notes",
-                                    _("Lower Notes"), gnotes_lower, 0);
-    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "hide-notes",
-                                    _("Hide Notes"), gnotes_hide, 0);
-    applet_widget_register_callback(APPLET_WIDGET(gnotes.applet), "show-notes",
-                                    _("Show Notes"), gnotes_show, 0);
-
     /* let's load us some notes! */
     gnotes_load(0, 0);
 
