@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.10 2000/04/20 04:51:04 jrb Exp $ */
+/* $Id: gweather-pref.c,v 1.11 2000/04/25 03:02:01 dmueth Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -44,7 +44,7 @@ static GtkWidget *pref_net_proxy_passwd_entry;
 static GtkWidget *pref_loc_ctree;
 static GtkCTreeNode *pref_loc_root;
 static GtkCTreeNode *pref_loc_sel_node = NULL;
-static GnomeHelpMenuEntry help_entry = { "gweather_applet", "index.html"};
+static GnomeHelpMenuEntry help_entry = { "gweather_applet", "index.html#GWEATHER-PREFS"};
 
 
 static gint cmp_loc (const WeatherLocation *l1, const WeatherLocation *l2)
