@@ -576,9 +576,9 @@ load_graph_properties_init (GnomePropertyObject *object)
     };
 
     static glong adj_data_descr [3*8] = {
-	1, 0, 0, 1, INT_MAX, 1, 256, 256,
-	1, 0, 0, 1, INT_MAX, 1, 256, 256,
-	1, 0, 0, 1, INT_MAX, 1, 256, 256
+	1, 0, 0, 1, G_MAXINT, 1, 256, 256,
+	1, 0, 0, 1, G_MAXINT, 1, 256, 256,
+	1, 0, 0, 1, G_MAXINT, 1, 256, 256
     };
 
     vb = gtk_vbox_new (FALSE, 0);
@@ -768,9 +768,9 @@ load_graph_local_properties_init (GnomePropertyObject *object)
     };
 
     static glong adj_data_descr [3*8] = {
-	1, 0, 0, 1, INT_MAX, 1, 256, 256,
-	1, 0, 0, 1, INT_MAX, 1, 256, 256,
-	1, 0, 0, 1, INT_MAX, 1, 256, 256
+	1, 0, 0, 1, G_MAXINT, 1, 256, 256,
+	1, 0, 0, 1, G_MAXINT, 1, 256, 256,
+	1, 0, 0, 1, G_MAXINT, 1, 256, 256
     };
 
     vb = gtk_vbox_new (FALSE, 0);
